@@ -3,20 +3,18 @@ require "time"
 
 require "stamp/emitters/modifiable"
 require "stamp/emitters/am_pm"
+require "stamp/emitters/ambiguous"
 require "stamp/emitters/composite"
 require "stamp/emitters/delegate"
 require "stamp/emitters/lookup"
 require "stamp/emitters/ordinal"
 require "stamp/emitters/string"
 require "stamp/emitters/two_digit"
+require "stamp/disambiguator"
 require "stamp/translator"
 require "stamp/version"
 
 module Stamp
-  # Limits the number of formats that we memoize to prevent unbounded
-  # memory consumption.
-  MEMOIZATION_CAP = 999
-
   # Formats a date/time using a human-friendly example as a template.
   #
   # @param [String] example a human-friendly date/time example
@@ -33,18 +31,20 @@ module Stamp
   alias :stamp_like  :stamp
   alias :format_like :stamp
 
+  private
+
   # Memoizes the set of emitter objects for the given +example+ in
   # order to improve performance.
   def memoize_stamp_emitters(example)
     @@memoized_stamp_emitters ||= {}
-    @@memoized_stamp_emitters.clear if @@memoized_stamp_emitters.size > MEMOIZATION_CAP
     @@memoized_stamp_emitters[example] ||= stamp_emitters(example)
   end
 
   def stamp_emitters(example)
-    Translator.new.translate(example)
+    emitters = Translator.new.translate(example)
+    Disambiguator.new(emitters).disambiguate!
   end
 end
 
 Date.send(:include, ::Stamp)
-Time.send(:include, ::Stamp)
\ No newline at end of file
+Time.send(:include, ::Stamp)
